PEP: 220 Title: Coroutines, Generators, Continuations Version:
$Revision$ Last-Modified: $Date$ Author: gmcm\@hypernet.com (Gordon
McMillan) Status: Rejected Type: Informational Content-Type: text/x-rst
Created: 14-Aug-2000 Post-History:

Abstract
========

Demonstrates why the changes described in the stackless PEP are
desirable. A low-level continuations module exists. With it, coroutines
and generators and "green" threads can be written. A higher level module
that makes coroutines and generators easy to create is desirable (and
being worked on). The focus of this PEP is on showing how coroutines,
generators, and green threads can simplify common programming problems.

.. Local Variables: mode: indented-text indent-tabs-mode: nil End:
